@@ -2,12 +2,6 @@ package Test2::Tools::Tiny;
 use strict;
 use warnings;
 
-BEGIN {
-    if ("$]" < 5.008) {
-        require Test::Builder::IO::Scalar;
-    }
-}
-
 use Scalar::Util qw/blessed/;
 
 use Test2::Util qw/try/;
@@ -16,7 +10,7 @@ use Test2::API qw/context run_subtest test2_stack/;
 use Test2::Hub::Interceptor();
 use Test2::Hub::Interceptor::Terminator();
 
-our $VERSION = '1.302205';
+our $VERSION = '1.302206';
 
 BEGIN { require Exporter; our @ISA = qw(Exporter) }
 our @EXPORT = qw{
@@ -259,16 +253,9 @@ sub capture(&) {
         my ($out_fh, $err_fh);
 
         ($ok, $e) = try {
-          # Scalar refs as filehandles were added in 5.8.
-          if ("$]" >= 5.008) {
+            # Scalar refs as filehandles were added in 5.8.
             open($out_fh, '>', \$out) or die "Failed to open a temporary STDOUT: $!";
             open($err_fh, '>', \$err) or die "Failed to open a temporary STDERR: $!";
-          }
-          # Emulate scalar ref filehandles with a tie.
-          else {
-            $out_fh = Test::Builder::IO::Scalar->new(\$out) or die "Failed to open a temporary STDOUT";
-            $err_fh = Test::Builder::IO::Scalar->new(\$err) or die "Failed to open a temporary STDERR";
-          }
 
             test2_stack->top->format->set_handles([$out_fh, $err_fh, $out_fh]);
 
